package RFC::Prototype::111;

use strict;
use vars qw($VERSION);
$VERSION = '0.01';

use Filter::Util::Exec;

sub import {
    my($caller) = shift;
    my $filter = bless {};
    Filter::Util::Exec::filter_add($caller, $^X, '-e', <<'CODE');
my $curr_here_doc = '';
my $in_here_doc = 0;
my $curr_tag;
my($pre_code, $post_code);
my $quote_type;
sub filter {
    my $code = '';
    while(<>) {
        unless( $in_here_doc ) {
            if( ($pre_code, $quote_type, $curr_tag, $post_code) = $_ =~
                     m/(.*)\<\<(")(\w+)"(.*)/ )      #' ]))
            {
                $in_here_doc = 1;
                $code .= $pre_code;
                $quote_type ||= '"';
            }
            else {
                $code .= $_;
            }
        }
        else {
            if( /^(\s*)$curr_tag\s*$/ ) {
                my $indent = $1;
                $curr_here_doc =~ s/^$indent//msg;
                $code .= $quote_type.$curr_here_doc.$quote_type.$post_code;

                $curr_here_doc = '';
                $in_here_doc = 0;
            }
            else {
                $curr_here_doc .= $_;
            }
        }

        $_ = '';
    }

    print $code;
}

&filter;
CODE

}


=pod

=head1 NAME

RFC::Prototype::111 - Implements Perl 6 RFC 111


=head1 SYNOPSIS

  use RFC::Prototype::111;

  if( $is_fitting && $is_just ) {
      die <<"POEM";
        The old lie
       Dulce et decorum est
         pro patria mori
      POEM    
  }


=head1 DESCRIPTION

Two changes.

    1. Allows POD end tags to be indented.  The amount of space a tag is
       indented is the amount which will be clipped off of each line of
       the here-doc.  Tabs will B<NOT> be expanded.

    2. POD end tags may now be followed by trailing whitespace


=head1 AUTHOR

Michael G Schwern <schwern@pobox.com>

=cut

1;
